@@ -1,15 +1,15 @@
 #' Opens a web page associated with a DOI (digital object identifier).
 #'
 #' Uses the DOI name of a study reference to locate the e-journal website,
-#'    or reference/citation website in Web of Science or Google Scholar.  Opens
-#'    in default web-browser.    
+#'    or reference/citation website in Web of Science, Google Scholar, or 
+#'    CrossRef.  Opens in default web-browser.    
 #'
 #' @param theDOI A string that identifies an electronic document on the web.
 #' @param host A string that defines the domain link used to open the DOI.  The 
 #'    default, \code{"DOI"}, will open to the web page associated with 
 #'    the DOI (e.g., publisher website).  Other options include \code{"WOS"} that 
-#'    will open the DOI in Web of Science, and \code{"GS"} which will open the browser
-#'    to Google Scholar.
+#'    will open the DOI in Web of Science, \code{"GS"} in Google Scholar, and 
+#'    \code{"CRF"} in Crossref.
 #'
 #' @return NULL
 #'
@@ -27,7 +27,8 @@ browse_DOI <- function(theDOI,
   theDomain <- switch(host, 
                       DOI = "http://dx.doi.org/",
                       WOS = "http://ws.isiknowledge.com/cps/openurl/service?url_ver=Z39.88-2004&rft_id=info:doi/",
-                      GS  = "http://scholar.google.com/scholar?q="
+                      GS  = "http://scholar.google.com/scholar?q=",
+					  CRF = "https://search.crossref.org/?q="
   )
   browseURL(paste0(theDomain, theDOI))
 }
\ No newline at end of file
