@@ -42,37 +42,42 @@ effort_redistribute <- function (aDataFrame,
                                  save_split = FALSE,
                                  directory = getwd()) {
   
+  
+  if(remove_effort == 0) return(aDataFrame)
+  if(is.null(reviewers)) .metagearPROBLEM("error", 
+                                          "no reviewers were assigned")
+  if(is.null(aDataFrame)) .metagearPROBLEM("error", 
+                                           "a dataframe with refs was not specified")
+  
   split_dataFrame <- split(aDataFrame, aDataFrame[, column_name])
   redist_dataFrame <- split_dataFrame[reviewer]
   split_dataFrame[reviewer] <- NULL
   
-  if(is.null(reviewers) == TRUE) reviewers <- levels(aDataFrame[,column_name])
-
   if (length(reviewers) == 1) {
-    
+    .metagearPROBLEM("warning", 
+                     "since reviewers had only one team member, all effort was distributed to them")
     new_dataFrame <- redist_dataFrame
     new_dataFrame[[1]][column_name] <- reviewers
-    
+
   } else {
-  
-    if(remove_effort != 100) theTeam <- reviewers
-    else if (length(reviewers) < length(levels(aDataFrame[,column_name]))) theTeam <- reviewers
-    else theTeam <- reviewers[ -which(reviewers %in% reviewer)]
-    
+    theTeam <- reviewers
     number_reviewers <- length(theTeam)
     
-    if(!is.null(effort)) {
-        teamEffort <- (remove_effort/100) * round((number_reviewers * (effort / 100)))
+    if(is.null(effort)) {
+        teamEffort <- rep(ceiling(remove_effort/(number_reviewers - 1)), 
+                          number_reviewers - 1)
         effort <- c(100 - remove_effort, teamEffort)
-    }
-    
+        if(sum(effort) > 100) 
+          effort[number_reviewers] <- effort[number_reviewers] - (sum(effort) - 100)
+    } 
+  
     new_dataFrame <- list(effort_distribute(redist_dataFrame[[1]],
-                                        theTeam,
-                                        effort = effort,
-                                        column_name = column_name,
-                                        dual = FALSE,
-                                        initialize = FALSE,
-                                        save_split = FALSE))
+                                            theTeam,
+                                            effort = effort,
+                                            column_name = column_name,
+                                            dual = FALSE,
+                                            initialize = FALSE,
+                                            save_split = FALSE))
       
   } 
     
